
*{{
  font-size: 16px;
}}

.icon_button {{
  font-weight: normal;
}}

QPushButton.connection {{
  padding: 0px;
  margin: 0px;
  width: 12px;
  height: 12px;
  min-width: 12px;
  min-height: 12px;
  max-width: 12px;
  max-height: 12px;
  border-radius: 6px !important;
}}

QCheckBox::indicator {{
  width: 40px;
  height: 40px;
}}

QMainWindow::separator:vertical,
QSplitter::handle:horizontal {{
  width: 30px;
}}

QMainWindow::separator:horizontal,
QSplitter::handle:vertical {{
  height: 30px;
}}
